<template>
    <div>
        <section class="referral">
            <h1 class="referral__header">
                Реф. система
            </h1>
            <label class="desc" style="pointer-events: none; font-weight: 400;">
                За каждого приглашенного реферала вы получаете {{ ref_percent }}% с каждого пополнения реферала.
            </label>

            <!-- {{ ref_price }} руб. и  -->

            <div class="action__group mb-0 action__get" style="margin-top: 21px;">
                <label
                    class="form-label"
                    style="pointer-events: none; color: #767b8a;"
                >
                    Ваша реферальная ссылка:
                </label>
                <input
                    v-if="$root.user !== null"
                    style="font-family: inherit; padding: 12px 10px;margin-top: 10px;"
                    :value="domain + '/?invite=' + $root.user.id"
                    type="text"
                    class="action__input disabled"
                    readonly
                    disabled
                />
                <button class="copy-triggert copy-clipboard" @click="copy">Скопировать</button>
            </div>
            <div class="history">
                <table class="mt-3 mb-3" style="font-family: 'Rubik';">
                    <thead>
                        <tr>
                            <th>Рефералов</th>
                            <th>Доход</th>
                            <th>Процент</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td>{{ count_refs }}</td>
                            <td class="text-success">{{ Number(profit).toFixed(2) }}</td>
                            <td>{{ ref_percent }}%</td>
                        </tr>
                    </tbody>
                </table>
            </div>
        </section>
        <section class="referral">
            <table class="table">
                <thead class="table__head">
                    <tr class="table__head-row">
                        <td class="table__head-item">
                            Реферал
                        </td>
                        <td class="table__head-item">
                            Доход
                        </td>
                    </tr>
                </thead>
                <tbody class="table__body" :class="[tableLoading ? 'table-blur' : '']">
                    <tr class="table__body-row" v-for="ref in refs">
                        <td class="table__body-item table__padding">
                            {{ ref.login }}
                        </td>
                        <td class="table__body-item table__padding text-success">
                            {{ parseFloat(ref.earn).toFixed(2) }}
                        </td>
                    </tr>
                    <tr class="table__body-row" v-if="refs.length == 0 && !tableLoading">
                        <td colspan="2" class="table__body-item table__padding">
                            У вас нет рефералов
                        </td>
                    </tr>
                </tbody>
            </table>
            <div class="referral_search">
                <div class="page__switch">
                    <button 
                        class="page__prev" 
                        :class="[{
                            'page__prev--disabled': page == 1 || tableLoading
                        }]" 
                        @click="page--"
                    >
                        ‹
                    </button>
                    <span class="page__now">{{ page }}</span>
                    <button 
                        class="page__next" 
                        :class="[{
                            'page__prev--disabled': lastPage || tableLoading
                        }]" 
                        @click="page++"
                    >
                        ›
                    </button>
                </div>
                <input
                    v-model="search"
                    class="action__input referral"
                    placeholder="Введите имя пользователя"
                />
            </div>
        </section>
    </div>
</template>

<script>
export default {
    data() {
        return {
            ref_price: "...",
            ref_percent: "...",
            count_refs: 0,
            profit: 0,
            domain: '...',
            refs: [],
            page: 1,
            lastPage: false,
            tableLoading: true,
            search: '',
            timeout: null
        }
    },
    methods: {
        copy() {
            this.$copyText(this.domain + '/?invite=' + this.$root.user.id);
            notify({
                theme: 'green',
                text: 'Скопировано!'
            });
        },
        init() {
            this.$root.axios.post('/referrals/get', {
                page: this.page,
                search: this.search
            })
            .then(response => {
                const {data} = response;

                this.ref_price = data.ref_price;
                this.ref_percent = data.ref_percent;
                this.count_refs = data.count_refs;
                this.profit = data.profit;

                this.refs = data.refs;
                this.tableLoading = false;
                this.lastPage = data.lastpage;
            })
            .catch(error => {
                if(error.response.status == 401) this.$router.push({name: 'index'})
            })
        }
    },
    mounted() {
        this.domain = location.origin
        this.init()
    },
    watch: {
        page: function () {
            //this.refs = [];
            this.tableLoading = true;
            this.init()
        },
        search: function () {
            clearTimeout(this.timeout)
            this.timeout = setTimeout(() => {
                this.page = 1;
                this.tableLoading = true;
                this.init()
            }, 500);
        }
    }
}
</script>

<style scoped>
.table-blur {
    filter: blur(10px);
}
.referral_search {
    display: flex;
    justify-content: space-between;
    align-items: center;
    margin-top: -20px;
}
.action__input.referral {
    border: 1px solid #dee2e6;
    background: #fff;
    max-width: 320px;
    height: 40px
}
@media(max-width: 48em) {
    .page__switch {
        order: 1
    }
    .referral_search {
        flex-direction: column
    }
    .action__input.referral {
        margin-top: 20px
    }
}
.page__switch {
    display: flex;
    margin-top: 10px;
    margin-bottom: 20px;
}

.page__switch > button {
    position: relative;
    display: block;
    padding: 0.5rem 0.75rem;
    margin-left: -1px;
    line-height: 1.25;
    color: #007bff;
    background-color: #fff;
    border: 1px solid #dee2e6;
    cursor: pointer;
}

.page__prev--disabled {
    cursor: not-allowed;
    pointer-events: none
}

.page__now {
    padding: 10px;
    color: #4e6588
}

.table {
    display: table;
}

table {
    min-width: 100%;
    margin-top: 40px;
}
tbody {
    text-align: center;
    margin-top: 10px;
}
td {
    font-size: 18px;
}
.text-success {
    color:#28a745!important;
}
.referral:nth-child(1) {
    background: #fff;
    border-radius: 8px;
    padding: 25px;
    margin-bottom: 48px;
}
.referral__header {
    margin: 0 0 1rem;
}
.copy-triggert {
    position: absolute;
    right: 0px;
    top: 29px;
    height: 37px;
    width: 120px;
    line-height: 20px;
    padding: 10px 0;
    text-align: center;
    color: #ffffff;
    background: #2c80ff;
    border-radius: 4px;
    border: none;
    transition: all .4s;
    cursor: pointer;
}
</style>
